==> ubuntu_localizations-0.3.2.tar.gz: lib/src/l10n/ubuntu_localizations_he.dart <==
import 'ubuntu_localizations.dart';

/// The translations for Hebrew (`he`).
class UbuntuLocalizationsHe extends UbuntuLocalizations {
  UbuntuLocalizationsHe([String locale = 'he']) : super(locale);

  @override
  String get countryCode => 'IL';

  @override
  String get languageName => 'עברית';

  @override
  String get backAction => 'חזרה';

  @override
  String get continueAction => 'המשך';

  @override
  String get strongPassword => 'סיסמה חזקה';

  @override
  String get fairPassword => 'סיסמה סבירה';

  @override
  String get goodPassword => 'סיסמה טובה';

  @override
  String get weakPassword => 'סיסמה חלשה';

  @override
  String get altKey => 'Alt';

  @override
  String get controlKey => 'Control';

  @override
  String get metaKey => 'מטא';

  @override
  String get shiftKey => 'Shift';

  @override
  String get aboutLabel => 'על אודות';

  @override
  String get addLabel => 'הוספה';

  @override
  String get allLabel => 'הכול';

  @override
  String get applyLabel => 'החלה';

  @override
  String get ascendingLabel => 'סדר עולה';

  @override
  String get backLabel => 'חזרה';

  @override
  String get boldLabel => 'מודגש';

  @override
  String get bottomLabel => 'למטה';

  @override
  String get cancelLabel => 'ביטול';

  @override
  String get centerLabel => 'מרכז';

  @override
  String get clearLabel => 'פינוי';

  @override
  String get closeLabel => 'סגירה';

  @override
  String get colorLabel => 'צבע';

  @override
  String get connectLabel => 'התחברות';

  @override
  String get continueLabel => 'המשך';

  @override
  String get copyLabel => 'העתקה';

  @override
  String get createLabel => 'יצירה';

  @override
  String get cutLabel => 'גזירה';

  @override
  String get decreaseLabel => 'הקטנה';

  @override
  String get deleteLabel => 'מחיקה';

  @override
  String get descendingLabel => 'סדר יורד';

  @override
  String get discardLabel => 'התעלמות';

  @override
  String get disconnectLabel => 'ניתוק';

  @override
  String get doneLabel => 'בוצע';

  @override
  String get downloadLabel => 'הורדה';

  @override
  String get editLabel => 'עריכה';

  @override
  String get enterLabel => 'Enter';

  @override
  String get errorLabel => 'שגיאה';

  @override
  String get executeLabel => 'הפעלה';

  @override
  String get exitLabel => 'יציאה';

  @override
  String get fileLabel => 'קובץ';

  @override
  String get fillLabel => 'מילוי';

  @override
  String get findLabel => 'איתור';

  @override
  String get firstLabel => 'ראשון';

  @override
  String get fontLabel => 'גופן';

  @override
  String get forwardLabel => 'קדימה';

  @override
  String get fullscreenLabel => 'מסך מלא';

  @override
  String get goBackLabel => 'חזרה';

  @override
  String get helpLabel => 'עזרה';

  @override
  String get homeLabel => 'בית';

  @override
  String get importLabel => 'ייבוא';

  @override
  String get increaseLabel => 'הגדלה';

  @override
  String get indexLabel => 'מפתח';

  @override
  String get informationLabel => 'מידע';

  @override
  String get insertLabel => 'Insert';

  @override
  String get italicLabel => 'נטוי';

  @override
  String get landscapeLabel => 'לרוחב';

  @override
  String get lastLabel => 'אחרון';

  @override
  String get leaveLabel => 'לנטוש';

  @override
  String get leftLabel => 'שמאלה';

  @override
  String get mediaLabel => 'מדיה';

  @override
  String get networkLabel => 'רשת';

  @override
  String get newLabel => 'חדש';

  @override
  String get nextLabel => 'הבא';

  @override
  String get noLabel => 'לא';

  @override
  String get noneLabel => 'אין';

  @override
  String get normalLabel => 'רגיל';

  @override
  String get okLabel => 'אישור';

  @override
  String get openLabel => 'פתיחה';

  @override
  String get pasteLabel => 'הדבקה';

  @override
  String get pauseLabel => 'השהיה';

  @override
  String get playLabel => 'נגינה';

  @override
  String get portraitLabel => 'לאורך';

  @override
  String get preferencesLabel => 'העדפות';

  @override
  String get previousLabel => 'הקודם';

  @override
  String get printLabel => 'הדפסה';

  @override
  String get printPreviewLabel => 'תצוגה לפני הדפסה';

  @override
  String get propertiesLabel => 'מאפיינים';

  @override
  String get questionLabel => 'שאלה';

  @override
  String get quitLabel => 'יציאה';

  @override
  String get recordLabel => 'הקלטה';

  @override
  String get redoLabel => 'ביצוע מחדש';

  @override
  String get refreshLabel => 'רענון';

  @override
  String get removeLabel => 'הסרה';

  @override
  String get renameLabel => 'שינוי שם';

  @override
  String get resetLabel => 'איפוס';

  @override
  String get restoreLabel => 'שחזור';

  @override
  String get retryLabel => 'ניסיון חוזר';

  @override
  String get revertLabel => 'החזרה';

  @override
  String get rewindLabel => 'אחורה';

  @override
  String get rightLabel => 'ימינה';

  @override
  String get saveAsLabel => 'שמירה בשם';

  @override
  String get saveLabel => 'שמירה';

  @override
  String get searchLabel => 'חיפוש';

  @override
  String get selectAllLabel => 'בחירה בהכול';

  @override
  String get selectLabel => 'בחירה';

  @override
  String get sendLabel => 'שליחה';

  @override
  String get skipLabel => 'דילוג';

  @override
  String get sortLabel => 'מיון';

  @override
  String get stopLabel => 'עצירה';

  @override
  String get strikeThroughLabel => 'קו חוצה';

  @override
  String get submitLabel => 'הגשה';

  @override
  String get topLabel => 'למעלה';

  @override
  String get undoLabel => 'הסגה';

  @override
  String get updateLabel => 'עדכון';

  @override
  String get upLabel => 'מעלה';

  @override
  String get viewLabel => 'תצוגה';

  @override
  String get warningLabel => 'אזהרה';

  @override
  String get windowLabel => 'חלון';

  @override
  String get yesLabel => 'כן';

  @override
  String get zoomInLabel => 'התקרבות';

  @override
  String get zoomOutLabel => 'התרחקות';

  @override
  String get byte => 'ב׳';

  @override
  String get kilobyte => 'ק״ב';

  @override
  String get megabyte => 'מ״ב';

  @override
  String get gigabyte => 'ג״ב';

  @override
  String get terabyte => 'TB';

  @override
  String get petabyte => 'PB';
}

==> ubuntu_localizations-0.3.4.tar.gz: lib/src/l10n/ubuntu_localizations_he.dart <==
import 'ubuntu_localizations.dart';

/// The translations for Hebrew (`he`).
class UbuntuLocalizationsHe extends UbuntuLocalizations {
  UbuntuLocalizationsHe([String locale = 'he']) : super(locale);

  @override
  String get countryCode => 'IL';

  @override
  String get languageName => 'עברית';

  @override
  String get backAction => 'חזרה';

  @override
  String get continueAction => 'המשך';

  @override
  String get strongPassword => 'סיסמה חזקה';

  @override
  String get fairPassword => 'סיסמה סבירה';

  @override
  String get goodPassword => 'סיסמה טובה';

  @override
  String get weakPassword => 'סיסמה חלשה';

  @override
  String get altKey => 'Alt';

  @override
  String get controlKey => 'Control';

  @override
  String get metaKey => 'מטא';

  @override
  String get shiftKey => 'Shift';

  @override
  String get aboutLabel => 'על אודות';

  @override
  String get addLabel => 'הוספה';

  @override
  String get allLabel => 'הכול';

  @override
  String get applyLabel => 'החלה';

  @override
  String get ascendingLabel => 'סדר עולה';

  @override
  String get backLabel => 'חזרה';

  @override
  String get boldLabel => 'מודגש';

  @override
  String get bottomLabel => 'למטה';

  @override
  String get cancelLabel => 'ביטול';

  @override
  String get centerLabel => 'מרכז';

  @override
  String get clearLabel => 'פינוי';

  @override
  String get closeLabel => 'סגירה';

  @override
  String get colorLabel => 'צבע';

  @override
  String get connectLabel => 'התחברות';

  @override
  String get continueLabel => 'המשך';

  @override
  String get copyLabel => 'העתקה';

  @override
  String get createLabel => 'יצירה';

  @override
  String get cutLabel => 'גזירה';

  @override
  String get decreaseLabel => 'הקטנה';

  @override
  String get deleteLabel => 'מחיקה';

  @override
  String get descendingLabel => 'סדר יורד';

  @override
  String get discardLabel => 'התעלמות';

  @override
  String get disconnectLabel => 'ניתוק';

  @override
  String get doneLabel => 'בוצע';

  @override
  String get downloadLabel => 'הורדה';

  @override
  String get editLabel => 'עריכה';

  @override
  String get enterLabel => 'Enter';

  @override
  String get errorLabel => 'שגיאה';

  @override
  String get executeLabel => 'הפעלה';

  @override
  String get exitLabel => 'יציאה';

  @override
  String get fileLabel => 'קובץ';

  @override
  String get fillLabel => 'מילוי';

  @override
  String get findLabel => 'איתור';

  @override
  String get firstLabel => 'ראשון';

  @override
  String get fontLabel => 'גופן';

  @override
  String get forwardLabel => 'קדימה';

  @override
  String get fullscreenLabel => 'מסך מלא';

  @override
  String get goBackLabel => 'חזרה';

  @override
  String get helpLabel => 'עזרה';

  @override
  String get homeLabel => 'בית';

  @override
  String get importLabel => 'ייבוא';

  @override
  String get increaseLabel => 'הגדלה';

  @override
  String get indexLabel => 'מפתח';

  @override
  String get informationLabel => 'מידע';

  @override
  String get insertLabel => 'Insert';

  @override
  String get italicLabel => 'נטוי';

  @override
  String get landscapeLabel => 'לרוחב';

  @override
  String get lastLabel => 'אחרון';

  @override
  String get leaveLabel => 'לנטוש';

  @override
  String get leftLabel => 'שמאלה';

  @override
  String get mediaLabel => 'מדיה';

  @override
  String get networkLabel => 'רשת';

  @override
  String get newLabel => 'חדש';

  @override
  String get nextLabel => 'הבא';

  @override
  String get noLabel => 'לא';

  @override
  String get noneLabel => 'אין';

  @override
  String get normalLabel => 'רגיל';

  @override
  String get okLabel => 'אישור';

  @override
  String get openLabel => 'פתיחה';

  @override
  String get pasteLabel => 'הדבקה';

  @override
  String get pauseLabel => 'השהיה';

  @override
  String get playLabel => 'נגינה';

  @override
  String get portraitLabel => 'לאורך';

  @override
  String get preferencesLabel => 'העדפות';

  @override
  String get previousLabel => 'הקודם';

  @override
  String get printLabel => 'הדפסה';

  @override
  String get printPreviewLabel => 'תצוגה לפני הדפסה';

  @override
  String get propertiesLabel => 'מאפיינים';

  @override
  String get questionLabel => 'שאלה';

  @override
  String get quitLabel => 'יציאה';

  @override
  String get recordLabel => 'הקלטה';

  @override
  String get redoLabel => 'ביצוע מחדש';

  @override
  String get refreshLabel => 'רענון';

  @override
  String get removeLabel => 'הסרה';

  @override
  String get renameLabel => 'שינוי שם';

  @override
  String get resetLabel => 'איפוס';

  @override
  String get restartLabel => 'הפעלה מחדש';

  @override
  String get restoreLabel => 'שחזור';

  @override
  String get retryLabel => 'ניסיון חוזר';

  @override
  String get revertLabel => 'החזרה';

  @override
  String get rewindLabel => 'אחורה';

  @override
  String get rightLabel => 'ימינה';

  @override
  String get saveAsLabel => 'שמירה בשם';

  @override
  String get saveLabel => 'שמירה';

  @override
  String get searchLabel => 'חיפוש';

  @override
  String get selectAllLabel => 'בחירה בהכול';

  @override
  String get selectLabel => 'בחירה';

  @override
  String get sendLabel => 'שליחה';

  @override
  String get skipLabel => 'דילוג';

  @override
  String get sortLabel => 'מיון';

  @override
  String get stopLabel => 'עצירה';

  @override
  String get strikeThroughLabel => 'קו חוצה';

  @override
  String get submitLabel => 'הגשה';

  @override
  String get topLabel => 'למעלה';

  @override
  String get undoLabel => 'הסגה';

  @override
  String get updateLabel => 'עדכון';

  @override
  String get upLabel => 'מעלה';

  @override
  String get viewLabel => 'תצוגה';

  @override
  String get warningLabel => 'אזהרה';

  @override
  String get windowLabel => 'חלון';

  @override
  String get yesLabel => 'כן';

  @override
  String get zoomInLabel => 'התקרבות';

  @override
  String get zoomOutLabel => 'התרחקות';

  @override
  String get byte => 'ב׳';

  @override
  String get kilobyte => 'ק״ב';

  @override
  String get megabyte => 'מ״ב';

  @override
  String get gigabyte => 'ג״ב';

  @override
  String get terabyte => 'ט״ב';

  @override
  String get petabyte => 'פ״ב';
}
